@@ -3,7 +3,9 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003 Henrik Sandklef                    
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
+ *                      2004, 2005, 2006, 2007, 2008
+ *                      2009  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -597,12 +599,18 @@ xnee_get_application_parameters(xnee_data *xd);
 int
 xnee_set_new_window_pos (xnee_data *xd);
 
+int
+xnee_get_new_window_pos (xnee_data *xd);
+
 int
 xnee_get_new_window_pos_value (xnee_data *xd);
 
 int
 xnee_unset_new_window_pos (xnee_data *xd);
 
+int
+xnee_get_recall_window_pos (xnee_data *xd);
+
 int
 xnee_set_recall_window_pos (xnee_data *xd);
 
@@ -672,13 +680,9 @@ xnee_get_author_email_str(xnee_data *xd);
 char *
 xnee_get_char_str(xnee_data *xd);
 
-int
-xnee_set_first_list_str(xnee_data *xd, char *str);
-
 int
 xnee_set_all_clients_str(xnee_data *xd, char *str);
 
-
 int
 xnee_set_future_clients_str(xnee_data *xd, char *str);
 
@@ -824,4 +828,23 @@ xnee_set_retype_release_delay(xnee_data *xd, unsigned int delay);
 #define xnee_get_retype_release_delay(xd) \
   (xd->retype.key_release_delay)
 
+
+int
+xnee_set_project_file(xnee_data *xd, char *name);
+
+int 
+xnee_set_resolution_str (xnee_data *xd, char *str);
+
+int
+xnee_set_plugin_name(xnee_data *xd, char *str, unsigned char mode);
+
+int 
+xnee_set_xosd_feedback(xnee_data *xd);
+
+int
+xnee_set_stderr_feedback(xnee_data *xd);
+
+int 
+xnee_set_no_feedback(xnee_data *xd);
+
 #endif /* XNEE_SETGET_H */ 
