@@ -223,6 +223,13 @@ xnee_human_print_request (xnee_data *xd, XRecordInterceptData *xrecintd )
   int           request_type ;
   char  *request_name ;
   char  *name=" not defined " ;
+
+  if ( xrecintd == NULL)
+    {
+      return;
+    }
+
+
   xrec_data  = (XRecordDatum *) (xrecintd->data) ;
 
   request_type = (int)xrec_data->type ;
@@ -358,7 +365,6 @@ xnee_human_print_event_verbose (xnee_data *xd, XRecordInterceptData *xrecintd )
 {
   XRecordDatum *xrec_data  ;
   int           event_type ;
-  int i ;
 
   xrec_data  = (XRecordDatum *) (xrecintd->data) ;
   event_type = (int)xrec_data->type ;
@@ -1151,9 +1157,11 @@ xnee_print_ranges (xnee_data *xd, FILE *fp)
     }
 
 
-
   max=xnee_get_max_range(xd);
 
+  printf (" print ranges %d\n",max);
+  fprintf (fp," print ranges\n");
+
   fprintf (fp, "#########################################\n");
   fprintf (fp, "#          Recording ranges             #\n");
   fprintf (fp, "#########################################\n");
@@ -1739,7 +1747,7 @@ xnee_version(xnee_data* xd)
 {
   xnee_verbose ((xd, " --> xnee_version\n"));
   fprintf (stderr, "%s %s\n",PACKAGE, VERSION);
-  fprintf (stderr, "Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Henrik Sandklef \n");
+  fprintf (stderr, "Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Henrik Sandklef \n");
   fprintf (stderr, "%s and all its included programs come with ", PACKAGE);
   fprintf (stderr, "NO WARRANTY,\nto the extent permitted by law.\n" );
   fprintf (stderr, "This is free software, and you may redistribute\n");
@@ -1764,7 +1772,7 @@ xnee_print_xnee_data(xnee_data *xd)
   fprintf (stderr, "  xd->control: %u\n", (int)xd->control);
   fprintf (stderr, "  xd->fake:    %u\n", (int)xd->fake);
   fprintf (stderr, "  xd->grab:    %u\n", (int)xd->grab);
-  
+  return XNEE_OK;
 }
 
 
