@@ -7,7 +7,7 @@
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
- * as published by the Free Software Foundation; either version 2    
+ * as published by the Free Software Foundation; either version 3    
  * of the License, or any later version.                             
  *                                                                   
  *                                                                   
@@ -18,13 +18,14 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 #include <dlfcn.h>
 #include <libxnee/xnee.h>
 #include <libxnee/print.h>
+#include <libxnee/xnee_dl.h>
 
 
 /**************************************************************
@@ -49,7 +50,7 @@ xnee_dlopen (xnee_data *xd, char *dl, int flag)
  *                                                            *
  **************************************************************/
 void *
-xnee_dlsym (xnee_data *xd, void* handle, char *sym)
+xnee_dlsym (xnee_data *xd, void* handle, const char *sym)
 {
   xnee_verbose ((xd, " ---> xnee_dlsym\n"));
   xnee_verbose ((xd, " <--- xnee_dlsym\n"));
@@ -78,7 +79,7 @@ xnee_dlclose (xnee_data *xd, void* handle)
  *                                                            *
  *                                                            *
  **************************************************************/
-char* 
+const char* 
 xnee_dlerror (xnee_data *xd)
 {
   xnee_verbose ((xd, " ---> xnee_dlerror\n"));
