@@ -4,7 +4,8 @@
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
- *                      2004, 2005, 2006, 2007 Henrik Sandklef      
+ *                      2004, 2005, 2006, 2007, 2008
+ *                      2009 Henrik Sandklef      
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -55,7 +56,7 @@ xnee_record_dispatch2 (XPointer xpoint_xnee_data,
 		       XRecordInterceptData *data )
 {
 
-  if ( (!data->data) || (data==NULL) )
+  if ( (data==NULL) || (!data->data) )
     {
       XRecordFreeData(data);
       XNEE_DEBUG ( (stderr ," <-- xnee_human_dispatch()  \n"  ));
@@ -127,8 +128,8 @@ xnee_record_handle_event_printer(xnee_data * xd,
 				 XRecordDatum *xrec_data, 
 				 XRecordInterceptData *xrecintd)
 {
-  static int last_record_window_pos_win=0;
-  static int last_record_window_pos_par=0;
+  static unsigned int last_record_window_pos_win=0;
+  static unsigned int last_record_window_pos_par=0;
 
   KeyCode kc;
   XWindowAttributes window_attributes_return;
@@ -234,15 +235,16 @@ xnee_record_handle_event_printer(xnee_data * xd,
       break;
     case MotionNotify:  
       kc = 0;
-      screen = xnee_get_screen_nr(xd, 
+      ret = xnee_get_screen_nr(xd, 
 				  xd->data,
 				  xrec_data->event.u.keyButtonPointer.root);
-      if (screen<0)
+      if (ret<0)
 	{
 	  xnee_verbose((xd, "Could not find a screen, bailing out\n"));
 	  return XNEE_SCREEN_MISSING;
 	}
-      
+      screen = ret;
+
       do_print = xnee_save_or_print(xd, kc, XNEE_GRAB_MOUSE);
       fprintf (out,"0,%u,%d,%d,0,0,%u,%lu\n",
 	       event_type,
@@ -317,15 +319,15 @@ xnee_record_handle_event_printer(xnee_data * xd,
 	      xnee_verbose((xd," window has has name '%s'\n", win_name));
 	    }
 	  fprintf (out, 
-		   "%s:%d,%d:%d,%d,%d,%d,%d,%d:%dx%d+%d+%d:%d,%d:%s\n", 
+		   "%s:%d,%d:%u,%u,%u,%u,%u,%d:%dx%d+%d+%d:%d,%d:%s\n", 
 		   XNEE_NEW_WINDOW_MARK,
 		   rx,
 		   ry,
-		   xrec_data->event.u.reparent.event,
-		   xrec_data->event.u.reparent.window,
-		   xrec_data->event.u.reparent.parent,
-		   xrec_data->event.u.reparent.x,
-		   xrec_data->event.u.reparent.y,
+		   (unsigned int) xrec_data->event.u.reparent.event,
+		   (unsigned int) xrec_data->event.u.reparent.window,
+		   (unsigned int) xrec_data->event.u.reparent.parent,
+		   (unsigned int) xrec_data->event.u.reparent.x,
+		   (unsigned int) xrec_data->event.u.reparent.y,
 		   xrec_data->event.u.reparent.override,
 		   window_attributes_return.x,
 		   window_attributes_return.y,
@@ -355,6 +357,7 @@ xnee_record_handle_event_printer(xnee_data * xd,
       break;
     }
   
+  return XNEE_OK;
 }
 
 
@@ -440,7 +443,6 @@ xnee_record_handle_event ( xnee_data *xd, /*@null@*/ XRecordInterceptData *xreci
 
 
 
-
 /**************************************************************
  *                                                            *
  * xnee_record_dispatch                                       *
@@ -457,10 +459,9 @@ xnee_record_dispatch(XPointer xpoint_xnee_data,
   int           ret;
 
   XNEE_DEBUG ( (stderr ," --> xnee_record_dispatch()  \n"  ));
-  
-  if ( (!data->data) || (data==NULL) )
+
+  if ( (data==NULL) || (!data->data) )
     {
-      XRecordFreeData(data);
       XNEE_DEBUG ( (stderr ," <-- xnee_record_dispatch()  \n"  ));
       (void)xnee_process_count(XNEE_PROCESS_RESET);
       return;
@@ -523,9 +524,9 @@ xnee_record_dispatch(XPointer xpoint_xnee_data,
       break;   
     case XRecordClientStarted:
       xnee_verbose((xd,  "ClientStarted \n"));
-      fprintf(stderr,  "ClientStarted %d %d \n", 
-	      data->id_base, 
-	      data->data);
+      fprintf(stderr,  "ClientStarted %u %u \n", 
+	      (unsigned int) data->id_base, 
+	      (unsigned int) data->data);
       break;
     case XRecordClientDied:
       xnee_verbose((xd,  "ClientDied \n"));
@@ -566,7 +567,7 @@ xnee_human_dispatch(XPointer xpoint_xnee_data,
   
   XNEE_DEBUG ( (stderr ," --> xnee_human_dispatch()  \n"  ));
   
-  if ( (!data->data) || (data==NULL) )
+  if ( (data==NULL) || (!data->data) )
     {
       XRecordFreeData(data);
       XNEE_DEBUG ( (stderr ," <-- xnee_human_dispatch()  \n"  ));
@@ -601,8 +602,6 @@ xnee_human_dispatch(XPointer xpoint_xnee_data,
     }
 
   
-
-
   switch(data->category)
     {
     case XRecordFromClient:
