@@ -4,7 +4,8 @@
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003
- *                      2004, 2005, 2006, 2007 Henrik Sandklef              
+ *                      2004, 2005, 2006, 2007, 2008
+ *                      2009  Henrik Sandklef              
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -42,6 +43,7 @@
 #include "libxnee/xnee_session.h"
 #include "libxnee/xnee_utils.h"
 #include "libxnee/xnee_window.h"
+#include "libxnee/xnee_range.h"
 
 static int time_out_counter = 0;
 static int diff_counter     = 0;
@@ -270,6 +272,8 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 	}
 /*        ret = xnee_set_ranges(xd); */
     }
+
+  xnee_print_ranges(xd,stdout);
   
   if ( 
       (read_mode==XNEE_REPLAY_READ_REPLAY_DATA) || 
@@ -301,6 +305,8 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
            XNEE_RETURN_IF_ERR(ret);
 	}
 
+  xnee_print_ranges(xd,stdout);
+
       ret = xnee_expression_handle_session(xd, tmp, &xindata);
 
 /*       if ( ret == XNEE_PRIMITIVE_DATA ) { printf ("return XNEE_OK\n"); ret = XNEE_OK; } */
@@ -665,8 +671,8 @@ xnee_setup_rep_recording(xnee_data *xd)
 void 
 xnee_replay_dispatch (XPointer type_ref, XRecordInterceptData *data)
 {
-  static int last_record_window_pos_win=0;
-  static int last_record_window_pos_par=0;
+  static unsigned int last_record_window_pos_win = 0;
+  static unsigned int last_record_window_pos_par = 0;
   
   XRecordDatum *xrec_data;
   int           type;
@@ -680,7 +686,7 @@ xnee_replay_dispatch (XPointer type_ref, XRecordInterceptData *data)
       return;
     }
 
-  
+		      
 
 
   xrec_data  = (XRecordDatum *) (data->data) ;
@@ -732,7 +738,7 @@ xnee_replay_dispatch (XPointer type_ref, XRecordInterceptData *data)
 			xrec_data->event.u.reparent.parent) )
 		    {
 		      xnee_verbose((xd, "   xnee_replay adding window 0x%X\n",
-			      xrec_data->event.u.reparent.window));
+				    (unsigned int)xrec_data->event.u.reparent.window));
 
 		      xnee_window_add_attribute_received(xd, 
 							 &window_attributes_return,
