@@ -3,7 +3,8 @@
  *                                                                   
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
- *        Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Henrik Sandklef
+ *        Copyright (C) 1999, 2000, 2001, 2002, 2003, 
+ *                      2004, 2009  Henrik Sandklef
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -33,8 +34,13 @@
 #include "libxnee/xnee_record.h"
 #include "libxnee/xnee_replay.h"
 #include "libxnee/xnee_setget.h"
+#include "libxnee/xnee_session.h"
+#include "libxnee/xnee_utils.h"
 #include "libxnee/xnee_alloc.h"
+#include "libxnee/xnee_resource.h"
+#include "libxnee/xnee_plugin.h"
 #include "libxnee/feedback.h"
+#include "libxnee/xnee_range.h"
 
 
 
@@ -1386,14 +1392,14 @@ xnee_set_project_name(xnee_data *xd, char *str)
 }
 
 int
-xnee_set_plugin_name(xnee_data *xd, char *str)
+xnee_set_plugin_name(xnee_data *xd, char *str, unsigned char mode)
 {
   if (str==NULL)
     {
       return XNEE_NO_PLUGIN_FILE;
     }
 
-  return xnee_use_plugin(xd, str);
+  return xnee_use_plugin(xd, str, mode);
 }
 
 
@@ -1455,15 +1461,6 @@ xnee_set_author_email(xnee_data *xd, char *str){
   return XNEE_OK;
 }
 
-int
-xnee_set_first_list_str(xnee_data *xd, char *str)
-{
-  int ret = XNEE_OK;  
-  
-  ret = xnee_set_first_last(xd);
-  return ret;
-}
-
 #ifdef USE_OBSOLETE
 int
 xnee_set_first_list_str2(xnee_data *xd, char *str)
@@ -1816,6 +1813,7 @@ int
 xnee_set_xnee_data (xnee_data *xd)
 {
   xd_saved = xd;
+  return XNEE_OK;
 }
  
 int
